
# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from snaptrade_client.api.api_disclaimer_api import APIDisclaimerApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from snaptrade_client.api.api_disclaimer_api import APIDisclaimerApi
from snaptrade_client.api.api_status_api import APIStatusApi
from snaptrade_client.api.account_information_api import AccountInformationApi
from snaptrade_client.api.authentication_api import AuthenticationApi
from snaptrade_client.api.connections_api import ConnectionsApi
from snaptrade_client.api.error_logs_api import ErrorLogsApi
from snaptrade_client.api.options_api import OptionsApi
from snaptrade_client.api.portfolio_management_api import PortfolioManagementApi
from snaptrade_client.api.reference_data_api import ReferenceDataApi
from snaptrade_client.api.trading_api import TradingApi
from snaptrade_client.api.transactions_and_reporting_api import TransactionsAndReportingApi



"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import unittest

import snaptrade_client
from snaptrade_client.api.trading_api import TradingApi  # noqa: E501


class TestTradingApi(unittest.TestCase):
    """TradingApi unit test stubs"""

    def setUp(self):
        self.api = TradingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_user_account_order(self):
        """Test case for cancel_user_account_order

        Cancel open order in account  # noqa: E501
        """
        pass

    def test_get_calculated_trade_impact_by_id(self):
        """Test case for get_calculated_trade_impact_by_id

        Return details of a specific trade before it's placed  # noqa: E501
        """
        pass

    def test_get_calculated_trades_impact(self):
        """Test case for get_calculated_trades_impact

        Return the impact of placing a series of trades on the portfolio  # noqa: E501
        """
        pass

    def test_get_order_impact(self):
        """Test case for get_order_impact

        Check impact of trades on account.  # noqa: E501
        """
        pass

    def test_get_user_account_quotes(self):
        """Test case for get_user_account_quotes

        Get symbol quotes  # noqa: E501
        """
        pass

    def test_modify_calculated_trade_by_id(self):
        """Test case for modify_calculated_trade_by_id

        Modify units of a trade before it is placed  # noqa: E501
        """
        pass

    def test_place_calculated_trades(self):
        """Test case for place_calculated_trades

        Place orders for the CalculatedTrades in series  # noqa: E501
        """
        pass

    def test_place_force_order(self):
        """Test case for place_force_order

        Place a trade with NO validation.  # noqa: E501
        """
        pass

    def test_place_oco_order(self):
        """Test case for place_oco_order

        Place a OCO (One Cancels Other) order  # noqa: E501
        """
        pass

    def test_place_order(self):
        """Test case for place_order

        Place order  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import re  # noqa: F401
import sys  # noqa: F401

from snaptrade_client.api_client import ApiClient, Endpoint as _Endpoint
from snaptrade_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from snaptrade_client.model.account_order_record import AccountOrderRecord
from snaptrade_client.model.manual_trade_and_impact import ManualTradeAndImpact
from snaptrade_client.model.manual_trade_form import ManualTradeForm
from snaptrade_client.model.model400_failed_request_response import Model400FailedRequestResponse
from snaptrade_client.model.model403_failed_request_response import Model403FailedRequestResponse
from snaptrade_client.model.symbols_quotes import SymbolsQuotes
from snaptrade_client.model.trade import Trade
from snaptrade_client.model.trade_execution_status import TradeExecutionStatus
from snaptrade_client.model.trade_impact import TradeImpact
from snaptrade_client.model.trading_place_oco_order_request import TradingPlaceOCOOrderRequest


class TradingApi(object):
    """NOTE: This class is auto generated by Konfig
    Ref: https://konfigthis.com

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.cancel_user_account_order_endpoint = _Endpoint(
            settings={
                'response_type': (AccountOrderRecord,),
                'auth': [
                    'PartnerClientId',
                    'PartnerSignature',
                    'PartnerTimestamp'
                ],
                'endpoint_path': '/accounts/{accountId}/orders/cancel',
                'operation_id': 'cancel_user_account_order',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'user_id',
                    'user_secret',
                    'account_id',
                    'body',
                ],
                'required': [
                    'user_id',
                    'user_secret',
                    'account_id',
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'user_id':
                        (str,),
                    'user_secret':
                        (str,),
                    'account_id':
                        (str,),
                    'body':
                        (str,),
                },
                'attribute_map': {
                    'user_id': 'userId',
                    'user_secret': 'userSecret',
                    'account_id': 'accountId',
                },
                'location_map': {
                    'user_id': 'query',
                    'user_secret': 'query',
                    'account_id': 'path',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.get_calculated_trade_impact_by_id_endpoint = _Endpoint(
            settings={
                'response_type': (Trade,),
                'auth': [
                    'PartnerClientId',
                    'PartnerSignature',
                    'PartnerTimestamp'
                ],
                'endpoint_path': '/portfolioGroups/{portfolioGroupId}/calculatedtrades/{calculatedTradeId}/modify/{tradeId}',
                'operation_id': 'get_calculated_trade_impact_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'portfolio_group_id',
                    'calculated_trade_id',
                    'trade_id',
                ],
                'required': [
                    'portfolio_group_id',
                    'calculated_trade_id',
                    'trade_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'portfolio_group_id':
                        (str,),
                    'calculated_trade_id':
                        (str,),
                    'trade_id':
                        (str,),
                },
                'attribute_map': {
                    'portfolio_group_id': 'portfolioGroupId',
                    'calculated_trade_id': 'calculatedTradeId',
                    'trade_id': 'tradeId',
                },
                'location_map': {
                    'portfolio_group_id': 'path',
                    'calculated_trade_id': 'path',
                    'trade_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_calculated_trades_impact_endpoint = _Endpoint(
            settings={
                'response_type': ([TradeImpact],),
                'auth': [
                    'PartnerClientId',
                    'PartnerSignature',
                    'PartnerTimestamp'
                ],
                'endpoint_path': '/portfolioGroups/{portfolioGroupId}/calculatedtrades/{calculatedTradeId}/impact',
                'operation_id': 'get_calculated_trades_impact',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'portfolio_group_id',
                    'calculated_trade_id',
                ],
                'required': [
                    'portfolio_group_id',
                    'calculated_trade_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'portfolio_group_id':
                        (str,),
                    'calculated_trade_id':
                        (str,),
                },
                'attribute_map': {
                    'portfolio_group_id': 'portfolioGroupId',
                    'calculated_trade_id': 'calculatedTradeId',
                },
                'location_map': {
                    'portfolio_group_id': 'path',
                    'calculated_trade_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_order_impact_endpoint = _Endpoint(
            settings={
                'response_type': (ManualTradeAndImpact,),
                'auth': [
                    'PartnerClientId',
                    'PartnerSignature',
                    'PartnerTimestamp'
                ],
                'endpoint_path': '/trade/impact',
                'operation_id': 'get_order_impact',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'user_id',
                    'user_secret',
                    'manual_trade_form',
                ],
                'required': [
                    'user_id',
                    'user_secret',
                    'manual_trade_form',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'user_id':
                        (str,),
                    'user_secret':
                        (str,),
                    'manual_trade_form':
                        (ManualTradeForm,),
                },
                'attribute_map': {
                    'user_id': 'userId',
                    'user_secret': 'userSecret',
                },
                'location_map': {
                    'user_id': 'query',
                    'user_secret': 'query',
                    'manual_trade_form': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.get_user_account_quotes_endpoint = _Endpoint(
            settings={
                'response_type': (SymbolsQuotes,),
                'auth': [
                    'PartnerClientId',
                    'PartnerSignature',
                    'PartnerTimestamp'
                ],
                'endpoint_path': '/accounts/{accountId}/quotes',
                'operation_id': 'get_user_account_quotes',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'user_id',
                    'user_secret',
                    'symbols',
                    'account_id',
                    'use_ticker',
                ],
                'required': [
                    'user_id',
                    'user_secret',
                    'symbols',
                    'account_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'user_id':
                        (str,),
                    'user_secret':
                        (str,),
                    'symbols':
                        (str,),
                    'account_id':
                        (str,),
                    'use_ticker':
                        (bool,),
                },
                'attribute_map': {
                    'user_id': 'userId',
                    'user_secret': 'userSecret',
                    'symbols': 'symbols',
                    'account_id': 'accountId',
                    'use_ticker': 'use_ticker',
                },
                'location_map': {
                    'user_id': 'query',
                    'user_secret': 'query',
                    'symbols': 'query',
                    'account_id': 'path',
                    'use_ticker': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.modify_calculated_trade_by_id_endpoint = _Endpoint(
            settings={
                'response_type': (Trade,),
                'auth': [
                    'PartnerClientId',
                    'PartnerSignature',
                    'PartnerTimestamp'
                ],
                'endpoint_path': '/portfolioGroups/{portfolioGroupId}/calculatedtrades/{calculatedTradeId}/modify/{tradeId}',
                'operation_id': 'modify_calculated_trade_by_id',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'portfolio_group_id',
                    'calculated_trade_id',
                    'trade_id',
                    'trade',
                ],
                'required': [
                    'portfolio_group_id',
                    'calculated_trade_id',
                    'trade_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'portfolio_group_id':
                        (str,),
                    'calculated_trade_id':
                        (str,),
                    'trade_id':
                        (str,),
                    'trade':
                        (Trade,),
                },
                'attribute_map': {
                    'portfolio_group_id': 'portfolioGroupId',
                    'calculated_trade_id': 'calculatedTradeId',
                    'trade_id': 'tradeId',
                },
                'location_map': {
                    'portfolio_group_id': 'path',
                    'calculated_trade_id': 'path',
                    'trade_id': 'path',
                    'trade': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.place_calculated_trades_endpoint = _Endpoint(
            settings={
                'response_type': ([TradeExecutionStatus],),
                'auth': [
                    'PartnerClientId',
                    'PartnerSignature',
                    'PartnerTimestamp'
                ],
                'endpoint_path': '/portfolioGroups/{portfolioGroupId}/calculatedtrades/{calculatedTradeId}/placeOrders',
                'operation_id': 'place_calculated_trades',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'portfolio_group_id',
                    'calculated_trade_id',
                ],
                'required': [
                    'portfolio_group_id',
                    'calculated_trade_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'portfolio_group_id':
                        (str,),
                    'calculated_trade_id':
                        (str,),
                },
                'attribute_map': {
                    'portfolio_group_id': 'portfolioGroupId',
                    'calculated_trade_id': 'calculatedTradeId',
                },
                'location_map': {
                    'portfolio_group_id': 'path',
                    'calculated_trade_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.place_force_order_endpoint = _Endpoint(
            settings={
                'response_type': (AccountOrderRecord,),
                'auth': [
                    'PartnerClientId',
                    'PartnerSignature',
                    'PartnerTimestamp'
                ],
                'endpoint_path': '/trade/place',
                'operation_id': 'place_force_order',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'user_id',
                    'user_secret',
                    'manual_trade_form',
                ],
                'required': [
                    'user_id',
                    'user_secret',
                    'manual_trade_form',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'user_id':
                        (str,),
                    'user_secret':
                        (str,),
                    'manual_trade_form':
                        (ManualTradeForm,),
                },
                'attribute_map': {
                    'user_id': 'userId',
                    'user_secret': 'userSecret',
                },
                'location_map': {
                    'user_id': 'query',
                    'user_secret': 'query',
                    'manual_trade_form': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.place_oco_order_endpoint = _Endpoint(
            settings={
                'response_type': (AccountOrderRecord,),
                'auth': [
                    'PartnerClientId',
                    'PartnerSignature',
                    'PartnerTimestamp'
                ],
                'endpoint_path': '/trade/oco',
                'operation_id': 'place_oco_order',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'user_id',
                    'user_secret',
                    'trading_place_oco_order_request',
                ],
                'required': [
                    'user_id',
                    'user_secret',
                    'trading_place_oco_order_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'user_id':
                        (str,),
                    'user_secret':
                        (str,),
                    'trading_place_oco_order_request':
                        (TradingPlaceOCOOrderRequest,),
                },
                'attribute_map': {
                    'user_id': 'userId',
                    'user_secret': 'userSecret',
                },
                'location_map': {
                    'user_id': 'query',
                    'user_secret': 'query',
                    'trading_place_oco_order_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.place_order_endpoint = _Endpoint(
            settings={
                'response_type': (AccountOrderRecord,),
                'auth': [
                    'PartnerClientId',
                    'PartnerSignature',
                    'PartnerTimestamp'
                ],
                'endpoint_path': '/trade/{tradeId}',
                'operation_id': 'place_order',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'trade_id',
                    'user_id',
                    'user_secret',
                ],
                'required': [
                    'trade_id',
                    'user_id',
                    'user_secret',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'trade_id':
                        (str,),
                    'user_id':
                        (str,),
                    'user_secret':
                        (str,),
                },
                'attribute_map': {
                    'trade_id': 'tradeId',
                    'user_id': 'userId',
                    'user_secret': 'userSecret',
                },
                'location_map': {
                    'trade_id': 'path',
                    'user_id': 'query',
                    'user_secret': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def cancel_user_account_order(
        self,
        user_id,
        user_secret,
        account_id,
        body,
        **kwargs
    ):
        """Cancel open order in account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.cancel_user_account_order(user_id, user_secret, account_id, body, async_req=True)
        >>> result = thread.get()

        Args:
            user_id (str):
            user_secret (str):
            account_id (str): The ID of the account get positions.
            body (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            AccountOrderRecord
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['user_id'] = \
            user_id
        kwargs['user_secret'] = \
            user_secret
        kwargs['account_id'] = \
            account_id
        kwargs['body'] = \
            body
        return self.cancel_user_account_order_endpoint.call_with_http_info(**kwargs)

    def get_calculated_trade_impact_by_id(
        self,
        portfolio_group_id,
        calculated_trade_id,
        trade_id,
        **kwargs
    ):
        """Return details of a specific trade before it's placed  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_calculated_trade_impact_by_id(portfolio_group_id, calculated_trade_id, trade_id, async_req=True)
        >>> result = thread.get()

        Args:
            portfolio_group_id (str): The ID of the PortfolioGroup to perform rebalancing calculations
            calculated_trade_id (str): The ID of calculated trade to get account impact
            trade_id (str): The ID of trade object

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            Trade
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['portfolio_group_id'] = \
            portfolio_group_id
        kwargs['calculated_trade_id'] = \
            calculated_trade_id
        kwargs['trade_id'] = \
            trade_id
        return self.get_calculated_trade_impact_by_id_endpoint.call_with_http_info(**kwargs)

    def get_calculated_trades_impact(
        self,
        portfolio_group_id,
        calculated_trade_id,
        **kwargs
    ):
        """Return the impact of placing a series of trades on the portfolio  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_calculated_trades_impact(portfolio_group_id, calculated_trade_id, async_req=True)
        >>> result = thread.get()

        Args:
            portfolio_group_id (str): The ID of the PortfolioGroup to perform rebalancing calculations
            calculated_trade_id (str): The ID of calculated trade to get account impact

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [TradeImpact]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['portfolio_group_id'] = \
            portfolio_group_id
        kwargs['calculated_trade_id'] = \
            calculated_trade_id
        return self.get_calculated_trades_impact_endpoint.call_with_http_info(**kwargs)

    def get_order_impact(
        self,
        user_id,
        user_secret,
        manual_trade_form,
        **kwargs
    ):
        """Check impact of trades on account.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_order_impact(user_id, user_secret, manual_trade_form, async_req=True)
        >>> result = thread.get()

        Args:
            user_id (str):
            user_secret (str):
            manual_trade_form (ManualTradeForm):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ManualTradeAndImpact
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['user_id'] = \
            user_id
        kwargs['user_secret'] = \
            user_secret
        kwargs['manual_trade_form'] = \
            manual_trade_form
        return self.get_order_impact_endpoint.call_with_http_info(**kwargs)

    def get_user_account_quotes(
        self,
        user_id,
        user_secret,
        symbols,
        account_id,
        **kwargs
    ):
        """Get symbol quotes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_user_account_quotes(user_id, user_secret, symbols, account_id, async_req=True)
        >>> result = thread.get()

        Args:
            user_id (str):
            user_secret (str):
            symbols (str): List of universal_symbol_id or tickers to get quotes for.
            account_id (str): The ID of the account to get quotes.

        Keyword Args:
            use_ticker (bool): Should be set to True if providing tickers.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            SymbolsQuotes
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['user_id'] = \
            user_id
        kwargs['user_secret'] = \
            user_secret
        kwargs['symbols'] = \
            symbols
        kwargs['account_id'] = \
            account_id
        return self.get_user_account_quotes_endpoint.call_with_http_info(**kwargs)

    def modify_calculated_trade_by_id(
        self,
        portfolio_group_id,
        calculated_trade_id,
        trade_id,
        **kwargs
    ):
        """Modify units of a trade before it is placed  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.modify_calculated_trade_by_id(portfolio_group_id, calculated_trade_id, trade_id, async_req=True)
        >>> result = thread.get()

        Args:
            portfolio_group_id (str): The ID of the PortfolioGroup to perform rebalancing calculations
            calculated_trade_id (str): The ID of calculated trade to get account impact
            trade_id (str): The ID of trade object

        Keyword Args:
            trade (Trade): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            Trade
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['portfolio_group_id'] = \
            portfolio_group_id
        kwargs['calculated_trade_id'] = \
            calculated_trade_id
        kwargs['trade_id'] = \
            trade_id
        return self.modify_calculated_trade_by_id_endpoint.call_with_http_info(**kwargs)

    def place_calculated_trades(
        self,
        portfolio_group_id,
        calculated_trade_id,
        **kwargs
    ):
        """Place orders for the CalculatedTrades in series  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.place_calculated_trades(portfolio_group_id, calculated_trade_id, async_req=True)
        >>> result = thread.get()

        Args:
            portfolio_group_id (str): The ID of the PortfolioGroup to perform rebalancing calculations
            calculated_trade_id (str): The ID of calculated trade to get account impact

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [TradeExecutionStatus]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['portfolio_group_id'] = \
            portfolio_group_id
        kwargs['calculated_trade_id'] = \
            calculated_trade_id
        return self.place_calculated_trades_endpoint.call_with_http_info(**kwargs)

    def place_force_order(
        self,
        user_id,
        user_secret,
        manual_trade_form,
        **kwargs
    ):
        """Place a trade with NO validation.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.place_force_order(user_id, user_secret, manual_trade_form, async_req=True)
        >>> result = thread.get()

        Args:
            user_id (str):
            user_secret (str):
            manual_trade_form (ManualTradeForm):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            AccountOrderRecord
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['user_id'] = \
            user_id
        kwargs['user_secret'] = \
            user_secret
        kwargs['manual_trade_form'] = \
            manual_trade_form
        return self.place_force_order_endpoint.call_with_http_info(**kwargs)

    def place_oco_order(
        self,
        user_id,
        user_secret,
        trading_place_oco_order_request,
        **kwargs
    ):
        """Place a OCO (One Cancels Other) order  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.place_oco_order(user_id, user_secret, trading_place_oco_order_request, async_req=True)
        >>> result = thread.get()

        Args:
            user_id (str):
            user_secret (str):
            trading_place_oco_order_request (TradingPlaceOCOOrderRequest):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            AccountOrderRecord
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['user_id'] = \
            user_id
        kwargs['user_secret'] = \
            user_secret
        kwargs['trading_place_oco_order_request'] = \
            trading_place_oco_order_request
        return self.place_oco_order_endpoint.call_with_http_info(**kwargs)

    def place_order(
        self,
        trade_id,
        user_id,
        user_secret,
        **kwargs
    ):
        """Place order  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.place_order(trade_id, user_id, user_secret, async_req=True)
        >>> result = thread.get()

        Args:
            trade_id (str): The ID of trade object obtained from trade/impact endpoint
            user_id (str):
            user_secret (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            AccountOrderRecord
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['trade_id'] = \
            trade_id
        kwargs['user_id'] = \
            user_id
        kwargs['user_secret'] = \
            user_secret
        return self.place_order_endpoint.call_with_http_info(**kwargs)




"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import re  # noqa: F401
import sys  # noqa: F401

from snaptrade_client.api_client import ApiClient, Endpoint as _Endpoint
from snaptrade_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from snaptrade_client.model.performance_custom import PerformanceCustom
from snaptrade_client.model.universal_activity import UniversalActivity


class TransactionsAndReportingApi(object):
    """NOTE: This class is auto generated by Konfig
    Ref: https://konfigthis.com

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.get_activities_endpoint = _Endpoint(
            settings={
                'response_type': ([UniversalActivity],),
                'auth': [
                    'PartnerClientId',
                    'PartnerSignature',
                    'PartnerTimestamp'
                ],
                'endpoint_path': '/activities',
                'operation_id': 'get_activities',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'user_id',
                    'user_secret',
                    'start_date',
                    'end_date',
                    'accounts',
                ],
                'required': [
                    'user_id',
                    'user_secret',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'user_id':
                        (str,),
                    'user_secret':
                        (str,),
                    'start_date':
                        (str,),
                    'end_date':
                        (str,),
                    'accounts':
                        (str,),
                },
                'attribute_map': {
                    'user_id': 'userId',
                    'user_secret': 'userSecret',
                    'start_date': 'startDate',
                    'end_date': 'endDate',
                    'accounts': 'accounts',
                },
                'location_map': {
                    'user_id': 'query',
                    'user_secret': 'query',
                    'start_date': 'query',
                    'end_date': 'query',
                    'accounts': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_reporting_custom_range_endpoint = _Endpoint(
            settings={
                'response_type': (PerformanceCustom,),
                'auth': [
                    'PartnerClientId',
                    'PartnerSignature',
                    'PartnerTimestamp'
                ],
                'endpoint_path': '/performance/custom',
                'operation_id': 'get_reporting_custom_range',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'start_date',
                    'end_date',
                    'user_id',
                    'user_secret',
                    'accounts',
                    'detailed',
                    'frequency',
                ],
                'required': [
                    'start_date',
                    'end_date',
                    'user_id',
                    'user_secret',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'start_date':
                        (str,),
                    'end_date':
                        (str,),
                    'user_id':
                        (str,),
                    'user_secret':
                        (str,),
                    'accounts':
                        (str,),
                    'detailed':
                        (bool,),
                    'frequency':
                        (str,),
                },
                'attribute_map': {
                    'start_date': 'startDate',
                    'end_date': 'endDate',
                    'user_id': 'userId',
                    'user_secret': 'userSecret',
                    'accounts': 'accounts',
                    'detailed': 'detailed',
                    'frequency': 'frequency',
                },
                'location_map': {
                    'start_date': 'query',
                    'end_date': 'query',
                    'user_id': 'query',
                    'user_secret': 'query',
                    'accounts': 'query',
                    'detailed': 'query',
                    'frequency': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def get_activities(
        self,
        user_id,
        user_secret,
        **kwargs
    ):
        """Get transaction history for a user  # noqa: E501

        Returns activities (transactions) for a user. Specifing start and end date is highly recommended for automatic calls for better performance  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_activities(user_id, user_secret, async_req=True)
        >>> result = thread.get()

        Args:
            user_id (str):
            user_secret (str):

        Keyword Args:
            start_date (str): [optional]
            end_date (str): [optional]
            accounts (str): Optional comma seperated list of account IDs used to filter the request on specific accounts. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [UniversalActivity]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['user_id'] = \
            user_id
        kwargs['user_secret'] = \
            user_secret
        return self.get_activities_endpoint.call_with_http_info(**kwargs)

    def get_reporting_custom_range(
        self,
        start_date,
        end_date,
        user_id,
        user_secret,
        **kwargs
    ):
        """Get performance information for a specific timeframe  # noqa: E501

        Returns performance information (contributions, dividends, rate of return, etc) for a specific timeframe. Total Equity Timeframe and Rate of Returns are experimental and should not be trusted to be 100% accurate  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_reporting_custom_range(start_date, end_date, user_id, user_secret, async_req=True)
        >>> result = thread.get()

        Args:
            start_date (str):
            end_date (str):
            user_id (str):
            user_secret (str):

        Keyword Args:
            accounts (str): Optional comma seperated list of account IDs used to filter the request on specific accounts. [optional]
            detailed (bool): Optional, increases frequency of data points for the total value and contribution charts if set to true. [optional]
            frequency (str): Optional frequency for the rate of return chart (defaults to monthly). Possible values are daily, weekly, monthly, quarterly, yearly.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            PerformanceCustom
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['start_date'] = \
            start_date
        kwargs['end_date'] = \
            end_date
        kwargs['user_id'] = \
            user_id
        kwargs['user_secret'] = \
            user_secret
        return self.get_reporting_custom_range_endpoint.call_with_http_info(**kwargs)




"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import sys
import unittest

import snaptrade_client
from snaptrade_client.model.manual_trade import ManualTrade
from snaptrade_client.model.manual_trade_balance import ManualTradeBalance
globals()['ManualTrade'] = ManualTrade
globals()['ManualTradeBalance'] = ManualTradeBalance
from snaptrade_client.model.manual_trade_and_impact import ManualTradeAndImpact


class TestManualTradeAndImpact(unittest.TestCase):
    """ManualTradeAndImpact unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testManualTradeAndImpact(self):
        """Test ManualTradeAndImpact"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ManualTradeAndImpact()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


__version__ = "2.2.0"

# import ApiClient
from snaptrade_client.api_client import ApiClient

# import Configuration
from snaptrade_client.configuration import Configuration

# import exceptions
from snaptrade_client.exceptions import OpenApiException
from snaptrade_client.exceptions import ApiAttributeError
from snaptrade_client.exceptions import ApiTypeError
from snaptrade_client.exceptions import ApiValueError
from snaptrade_client.exceptions import ApiKeyError
from snaptrade_client.exceptions import ApiException



"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import unittest

import snaptrade_client
from snaptrade_client.api.authentication_api import AuthenticationApi  # noqa: E501


class TestAuthenticationApi(unittest.TestCase):
    """AuthenticationApi unit test stubs"""

    def setUp(self):
        self.api = AuthenticationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_snap_trade_user(self):
        """Test case for delete_snap_trade_user

        Delete user from SnapTrade, disabling all brokerage authorizations and permanently deleting all data associated with the user  # noqa: E501
        """
        pass

    def test_get_user_jwt(self):
        """Test case for get_user_jwt

        Obtains an encrypted JWT tokens that should be decrypted on a user's local device  # noqa: E501
        """
        pass

    def test_list_snap_trade_users(self):
        """Test case for list_snap_trade_users

        Get a list of all SnapTrade users you've registered on our platform  # noqa: E501
        """
        pass

    def test_login_snap_trade_user(self):
        """Test case for login_snap_trade_user

        Generate a redirect URI to securely login a user to the SnapTrade Connection Portal  # noqa: E501
        """
        pass

    def test_register_snap_trade_user(self):
        """Test case for register_snap_trade_user

        Register user with SnapTrade in order to create secure brokerage authorizations  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import io
import json
import logging
import re
import ssl
import hmac
import time
import hashlib
from base64 import b64encode
from urllib.parse import urlencode
from urllib.parse import urlparse
from urllib.request import proxy_bypass_environment
import urllib3
import ipaddress

from snaptrade_client.exceptions import ApiException, UnauthorizedException, ForbiddenException, NotFoundException, ServiceException, ApiValueError


logger = logging.getLogger(__name__)


class RESTResponse(io.IOBase):

    def __init__(self, resp):
        self.urllib3_response = resp
        self.status = resp.status
        self.reason = resp.reason
        self.data = resp.data

    def getheaders(self):
        """Returns a dictionary of the response headers."""
        return self.urllib3_response.getheaders()

    def getheader(self, name, default=None):
        """Returns a given response header."""
        return self.urllib3_response.getheader(name, default)


class RESTClientObject(object):

    def __init__(self, configuration, pools_size=4, maxsize=None):
        # urllib3.PoolManager will pass all kw parameters to connectionpool
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/poolmanager.py#L75  # noqa: E501
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/connectionpool.py#L680  # noqa: E501
        # maxsize is the number of requests to host that are allowed in parallel  # noqa: E501
        # Custom SSL certificates and client certificates: http://urllib3.readthedocs.io/en/latest/advanced-usage.html  # noqa: E501
    
        self.consumer_key = configuration.consumer_key
        self.host = configuration.host

        # cert_reqs
        if configuration.verify_ssl:
            cert_reqs = ssl.CERT_REQUIRED
        else:
            cert_reqs = ssl.CERT_NONE

        addition_pool_args = {}
        if configuration.assert_hostname is not None:
            addition_pool_args['assert_hostname'] = configuration.assert_hostname  # noqa: E501

        if configuration.retries is not None:
            addition_pool_args['retries'] = configuration.retries

        if configuration.socket_options is not None:
            addition_pool_args['socket_options'] = configuration.socket_options

        if maxsize is None:
            if configuration.connection_pool_maxsize is not None:
                maxsize = configuration.connection_pool_maxsize
            else:
                maxsize = 4

        # https pool manager
        if configuration.proxy and not should_bypass_proxies(
                configuration.host, no_proxy=configuration.no_proxy or ''):
            self.pool_manager = urllib3.ProxyManager(
                num_pools=pools_size,
                maxsize=maxsize,
                cert_reqs=cert_reqs,
                ca_certs=configuration.ssl_ca_cert,
                cert_file=configuration.cert_file,
                key_file=configuration.key_file,
                proxy_url=configuration.proxy,
                proxy_headers=configuration.proxy_headers,
                **addition_pool_args
            )
        else:
            self.pool_manager = urllib3.PoolManager(
                num_pools=pools_size,
                maxsize=maxsize,
                cert_reqs=cert_reqs,
                ca_certs=configuration.ssl_ca_cert,
                cert_file=configuration.cert_file,
                key_file=configuration.key_file,
                **addition_pool_args
            )
 
    def compute_request_signature(self, url, query_params, body):
        path = url.replace(self.host, "")
        sig_object = {
            "content": body,
            "path": "/api/v1%s" % path,
            "query": urlencode(query_params)
        }
        sig_content = json.dumps(sig_object, separators=(",", ":"), sort_keys=True)
        sig_digest = hmac.new(self.consumer_key.encode(), sig_content.encode(), hashlib.sha256).digest()
        signature = b64encode(sig_digest).decode()
        return signature

    def request(self, method, url, query_params=None, headers=None,
                body=None, post_params=None, _preload_content=True,
                _request_timeout=None):
        """Perform requests.

        :param method: http request method
        :param url: http request url
        :param query_params: query parameters in the url
        :param headers: http request headers
        :param body: request json body, for `application/json`
        :param post_params: request post parameters,
                            `application/x-www-form-urlencoded`
                            and `multipart/form-data`
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        """
        method = method.upper()
        assert method in ['GET', 'HEAD', 'DELETE', 'POST', 'PUT',
                          'PATCH', 'OPTIONS']

        if post_params and body:
            raise ApiValueError(
                "body parameter cannot be used with post_params parameter."
            )

        post_params = post_params or {}
        headers = headers or {}

        timeout = None
        if _request_timeout:
            if isinstance(_request_timeout, (int, float)):  # noqa: E501,F821
                timeout = urllib3.Timeout(total=_request_timeout)
            elif (isinstance(_request_timeout, tuple) and
                  len(_request_timeout) == 2):
                timeout = urllib3.Timeout(
                    connect=_request_timeout[0], read=_request_timeout[1])
                     
        # Add Signature to header
        query_params.append(("timestamp", int(time.time())))
        headers['Signature'] = self.compute_request_signature(url, query_params, body)

        try:
            # For `POST`, `PUT`, `PATCH`, `OPTIONS`, `DELETE`
            if method in ['POST', 'PUT', 'PATCH', 'OPTIONS', 'DELETE']:
                # Only set a default Content-Type for POST, PUT, PATCH and OPTIONS requests
                if (method != 'DELETE') and ('Content-Type' not in headers):
                    headers['Content-Type'] = 'application/json'
                if query_params:
                    url += '?' + urlencode(query_params)
                if ('Content-Type' not in headers) or (re.search('json',
                                                                 headers['Content-Type'], re.IGNORECASE)):
                    request_body = None
                    if body is not None:
                        request_body = json.dumps(body)
                    r = self.pool_manager.request(
                        method, url,
                        body=request_body,
                        preload_content=_preload_content,
                        timeout=timeout,
                        headers=headers)
                elif headers['Content-Type'] == 'application/x-www-form-urlencoded':  # noqa: E501
                    r = self.pool_manager.request(
                        method, url,
                        fields=post_params,
                        encode_multipart=False,
                        preload_content=_preload_content,
                        timeout=timeout,
                        headers=headers)
                elif headers['Content-Type'] == 'multipart/form-data':
                    # must del headers['Content-Type'], or the correct
                    # Content-Type which generated by urllib3 will be
                    # overwritten.
                    del headers['Content-Type']
                    r = self.pool_manager.request(
                        method, url,
                        fields=post_params,
                        encode_multipart=True,
                        preload_content=_preload_content,
                        timeout=timeout,
                        headers=headers)
                # Pass a `string` parameter directly in the body to support
                # other content types than Json when `body` argument is
                # provided in serialized form
                elif isinstance(body, str) or isinstance(body, bytes):
                    request_body = body
                    r = self.pool_manager.request(
                        method, url,
                        body=request_body,
                        preload_content=_preload_content,
                        timeout=timeout,
                        headers=headers)
                else:
                    # Cannot generate the request from given parameters
                    msg = """Cannot prepare a request message for provided
                             arguments. Please check that your arguments match
                             declared content type."""
                    raise ApiException(status=0, reason=msg)
            # For `GET`, `HEAD`
            else:
                r = self.pool_manager.request(method, url,
                                              fields=query_params,
                                              preload_content=_preload_content,
                                              timeout=timeout,
                                              headers=headers)
        except urllib3.exceptions.SSLError as e:
            msg = "{0}\n{1}".format(type(e).__name__, str(e))
            raise ApiException(status=0, reason=msg)

        if _preload_content:
            r = RESTResponse(r)

            # log response body
            logger.debug("response body: %s", r.data)

        if not 200 <= r.status <= 299:
            if r.status == 401:
                raise UnauthorizedException(http_resp=r)

            if r.status == 403:
                raise ForbiddenException(http_resp=r)

            if r.status == 404:
                raise NotFoundException(http_resp=r)

            if 500 <= r.status <= 599:
                raise ServiceException(http_resp=r)

            raise ApiException(http_resp=r)

        return r

    def GET(self, url, headers=None, query_params=None, _preload_content=True,
            _request_timeout=None):
        return self.request("GET", url,
                            headers=headers,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            query_params=query_params)

    def HEAD(self, url, headers=None, query_params=None, _preload_content=True,
             _request_timeout=None):
        return self.request("HEAD", url,
                            headers=headers,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            query_params=query_params)

    def OPTIONS(self, url, headers=None, query_params=None, post_params=None,
                body=None, _preload_content=True, _request_timeout=None):
        return self.request("OPTIONS", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)

    def DELETE(self, url, headers=None, query_params=None, body=None,
               _preload_content=True, _request_timeout=None):
        return self.request("DELETE", url,
                            headers=headers,
                            query_params=query_params,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)

    def POST(self, url, headers=None, query_params=None, post_params=None,
             body=None, _preload_content=True, _request_timeout=None):
        return self.request("POST", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)

    def PUT(self, url, headers=None, query_params=None, post_params=None,
            body=None, _preload_content=True, _request_timeout=None):
        return self.request("PUT", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)

    def PATCH(self, url, headers=None, query_params=None, post_params=None,
              body=None, _preload_content=True, _request_timeout=None):
        return self.request("PATCH", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)

# end of class RESTClientObject


def is_ipv4(target):
    """ Test if IPv4 address or not
    """
    try:
        chk = ipaddress.IPv4Address(target)
        return True
    except ipaddress.AddressValueError:
        return False


def in_ipv4net(target, net):
    """ Test if target belongs to given IPv4 network
    """
    try:
        nw = ipaddress.IPv4Network(net)
        ip = ipaddress.IPv4Address(target)
        if ip in nw:
            return True
        return False
    except ipaddress.AddressValueError:
        return False
    except ipaddress.NetmaskValueError:
        return False


def should_bypass_proxies(url, no_proxy=None):
    """ Yet another requests.should_bypass_proxies
    Test if proxies should not be used for a particular url.
    """

    parsed = urlparse(url)

    # special cases
    if parsed.hostname in [None, '']:
        return True

    # special cases
    if no_proxy in [None, '']:
        return False
    if no_proxy == '*':
        return True

    no_proxy = no_proxy.lower().replace(' ', '');
    entries = (
        host for host in no_proxy.split(',') if host
    )

    if is_ipv4(parsed.hostname):
        for item in entries:
            if in_ipv4net(parsed.hostname, item):
                return True
    return proxy_bypass_environment(parsed.hostname, {'no': no_proxy})



"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import unittest

import snaptrade_client
from snaptrade_client.api.connections_api import ConnectionsApi  # noqa: E501


class TestConnectionsApi(unittest.TestCase):
    """ConnectionsApi unit test stubs"""

    def setUp(self):
        self.api = ConnectionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_detail_brokerage_authorization(self):
        """Test case for detail_brokerage_authorization

        Get detail of a specific brokerage authorizations for the user  # noqa: E501
        """
        pass

    def test_list_brokerage_authorizations(self):
        """Test case for list_brokerage_authorizations

        List all brokerage authorizations for the user  # noqa: E501
        """
        pass

    def test_remove_brokerage_authorization(self):
        """Test case for remove_brokerage_authorization

        Remove a brokerage authorization.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import unittest

import snaptrade_client
from snaptrade_client.api.error_logs_api import ErrorLogsApi  # noqa: E501


class TestErrorLogsApi(unittest.TestCase):
    """ErrorLogsApi unit test stubs"""

    def setUp(self):
        self.api = ErrorLogsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_list_user_errors(self):
        """Test case for list_user_errors

        Retrieve error logs on behalf of your SnapTrade users  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import re  # noqa: F401
import sys  # noqa: F401

from snaptrade_client.api_client import ApiClient, Endpoint as _Endpoint
from snaptrade_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from snaptrade_client.model.account import Account
from snaptrade_client.model.account_holdings import AccountHoldings
from snaptrade_client.model.account_order_record import AccountOrderRecord
from snaptrade_client.model.balance import Balance
from snaptrade_client.model.model400_failed_request_response import Model400FailedRequestResponse
from snaptrade_client.model.model403_failed_request_response import Model403FailedRequestResponse
from snaptrade_client.model.position import Position


class AccountInformationApi(object):
    """NOTE: This class is auto generated by Konfig
    Ref: https://konfigthis.com

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.get_all_user_holdings_endpoint = _Endpoint(
            settings={
                'response_type': ([AccountHoldings],),
                'auth': [
                    'PartnerClientId',
                    'PartnerSignature',
                    'PartnerTimestamp'
                ],
                'endpoint_path': '/holdings',
                'operation_id': 'get_all_user_holdings',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'user_id',
                    'user_secret',
                    'brokerage_authorizations',
                ],
                'required': [
                    'user_id',
                    'user_secret',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'user_id':
                        (str,),
                    'user_secret':
                        (str,),
                    'brokerage_authorizations':
                        (str,),
                },
                'attribute_map': {
                    'user_id': 'userId',
                    'user_secret': 'userSecret',
                    'brokerage_authorizations': 'brokerage_authorizations',
                },
                'location_map': {
                    'user_id': 'query',
                    'user_secret': 'query',
                    'brokerage_authorizations': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_user_account_balance_endpoint = _Endpoint(
            settings={
                'response_type': ([Balance],),
                'auth': [
                    'PartnerClientId',
                    'PartnerSignature',
                    'PartnerTimestamp'
                ],
                'endpoint_path': '/accounts/{accountId}/balances',
                'operation_id': 'get_user_account_balance',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'user_id',
                    'user_secret',
                    'account_id',
                ],
                'required': [
                    'user_id',
                    'user_secret',
                    'account_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'user_id':
                        (str,),
                    'user_secret':
                        (str,),
                    'account_id':
                        (str,),
                },
                'attribute_map': {
                    'user_id': 'userId',
                    'user_secret': 'userSecret',
                    'account_id': 'accountId',
                },
                'location_map': {
                    'user_id': 'query',
                    'user_secret': 'query',
                    'account_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    '*/*'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_user_account_details_endpoint = _Endpoint(
            settings={
                'response_type': ([Account],),
                'auth': [
                    'PartnerClientId',
                    'PartnerSignature',
                    'PartnerTimestamp'
                ],
                'endpoint_path': '/accounts/{accountId}',
                'operation_id': 'get_user_account_details',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'user_id',
                    'user_secret',
                    'account_id',
                ],
                'required': [
                    'user_id',
                    'user_secret',
                    'account_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'user_id':
                        (str,),
                    'user_secret':
                        (str,),
                    'account_id':
                        (str,),
                },
                'attribute_map': {
                    'user_id': 'userId',
                    'user_secret': 'userSecret',
                    'account_id': 'accountId',
                },
                'location_map': {
                    'user_id': 'query',
                    'user_secret': 'query',
                    'account_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_user_account_orders_endpoint = _Endpoint(
            settings={
                'response_type': ([AccountOrderRecord],),
                'auth': [
                    'PartnerClientId',
                    'PartnerSignature',
                    'PartnerTimestamp'
                ],
                'endpoint_path': '/accounts/{accountId}/orders',
                'operation_id': 'get_user_account_orders',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'user_id',
                    'user_secret',
                    'account_id',
                    'state',
                ],
                'required': [
                    'user_id',
                    'user_secret',
                    'account_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'state',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('state',): {

                        "ALL": "all",
                        "OPEN": "open",
                        "EXECUTED": "executed"
                    },
                },
                'openapi_types': {
                    'user_id':
                        (str,),
                    'user_secret':
                        (str,),
                    'account_id':
                        (str,),
                    'state':
                        (str,),
                },
                'attribute_map': {
                    'user_id': 'userId',
                    'user_secret': 'userSecret',
                    'account_id': 'accountId',
                    'state': 'state',
                },
                'location_map': {
                    'user_id': 'query',
                    'user_secret': 'query',
                    'account_id': 'path',
                    'state': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_user_account_positions_endpoint = _Endpoint(
            settings={
                'response_type': ([Position],),
                'auth': [
                    'PartnerClientId',
                    'PartnerSignature',
                    'PartnerTimestamp'
                ],
                'endpoint_path': '/accounts/{accountId}/positions',
                'operation_id': 'get_user_account_positions',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'user_id',
                    'user_secret',
                    'account_id',
                ],
                'required': [
                    'user_id',
                    'user_secret',
                    'account_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'user_id':
                        (str,),
                    'user_secret':
                        (str,),
                    'account_id':
                        (str,),
                },
                'attribute_map': {
                    'user_id': 'userId',
                    'user_secret': 'userSecret',
                    'account_id': 'accountId',
                },
                'location_map': {
                    'user_id': 'query',
                    'user_secret': 'query',
                    'account_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    '*/*'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_user_holdings_endpoint = _Endpoint(
            settings={
                'response_type': (AccountHoldings,),
                'auth': [
                    'PartnerClientId',
                    'PartnerSignature',
                    'PartnerTimestamp'
                ],
                'endpoint_path': '/accounts/{accountId}/holdings',
                'operation_id': 'get_user_holdings',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'account_id',
                    'user_id',
                    'user_secret',
                ],
                'required': [
                    'account_id',
                    'user_id',
                    'user_secret',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'account_id':
                        (str,),
                    'user_id':
                        (str,),
                    'user_secret':
                        (str,),
                },
                'attribute_map': {
                    'account_id': 'accountId',
                    'user_id': 'userId',
                    'user_secret': 'userSecret',
                },
                'location_map': {
                    'account_id': 'path',
                    'user_id': 'query',
                    'user_secret': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.list_user_accounts_endpoint = _Endpoint(
            settings={
                'response_type': ([Account],),
                'auth': [
                    'PartnerClientId',
                    'PartnerSignature',
                    'PartnerTimestamp'
                ],
                'endpoint_path': '/accounts',
                'operation_id': 'list_user_accounts',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'user_id',
                    'user_secret',
                ],
                'required': [
                    'user_id',
                    'user_secret',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'user_id':
                        (str,),
                    'user_secret':
                        (str,),
                },
                'attribute_map': {
                    'user_id': 'userId',
                    'user_secret': 'userSecret',
                },
                'location_map': {
                    'user_id': 'query',
                    'user_secret': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_user_account_endpoint = _Endpoint(
            settings={
                'response_type': ([Account],),
                'auth': [
                    'PartnerClientId',
                    'PartnerSignature',
                    'PartnerTimestamp'
                ],
                'endpoint_path': '/accounts/{accountId}',
                'operation_id': 'update_user_account',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'user_id',
                    'user_secret',
                    'account_id',
                ],
                'required': [
                    'user_id',
                    'user_secret',
                    'account_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'user_id':
                        (str,),
                    'user_secret':
                        (str,),
                    'account_id':
                        (str,),
                },
                'attribute_map': {
                    'user_id': 'userId',
                    'user_secret': 'userSecret',
                    'account_id': 'accountId',
                },
                'location_map': {
                    'user_id': 'query',
                    'user_secret': 'query',
                    'account_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def get_all_user_holdings(
        self,
        user_id,
        user_secret,
        **kwargs
    ):
        """List all accounts for the user, plus balances and positions for each account.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_all_user_holdings(user_id, user_secret, async_req=True)
        >>> result = thread.get()

        Args:
            user_id (str):
            user_secret (str):

        Keyword Args:
            brokerage_authorizations (str): Optional. Comma seperated list of authorization IDs (only use if filtering is needed on one or more authorizations).. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [AccountHoldings]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['user_id'] = \
            user_id
        kwargs['user_secret'] = \
            user_secret
        return self.get_all_user_holdings_endpoint.call_with_http_info(**kwargs)

    def get_user_account_balance(
        self,
        user_id,
        user_secret,
        account_id,
        **kwargs
    ):
        """Get all cash balances of an investment account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_user_account_balance(user_id, user_secret, account_id, async_req=True)
        >>> result = thread.get()

        Args:
            user_id (str):
            user_secret (str):
            account_id (str): The ID of the account get positions.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [Balance]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['user_id'] = \
            user_id
        kwargs['user_secret'] = \
            user_secret
        kwargs['account_id'] = \
            account_id
        return self.get_user_account_balance_endpoint.call_with_http_info(**kwargs)

    def get_user_account_details(
        self,
        user_id,
        user_secret,
        account_id,
        **kwargs
    ):
        """Return details of a specific investment account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_user_account_details(user_id, user_secret, account_id, async_req=True)
        >>> result = thread.get()

        Args:
            user_id (str):
            user_secret (str):
            account_id (str): The ID of the account to get detail of.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [Account]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['user_id'] = \
            user_id
        kwargs['user_secret'] = \
            user_secret
        kwargs['account_id'] = \
            account_id
        return self.get_user_account_details_endpoint.call_with_http_info(**kwargs)

    def get_user_account_orders(
        self,
        user_id,
        user_secret,
        account_id,
        **kwargs
    ):
        """Get all history of orders placed in account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_user_account_orders(user_id, user_secret, account_id, async_req=True)
        >>> result = thread.get()

        Args:
            user_id (str):
            user_secret (str):
            account_id (str): The ID of the account get positions.

        Keyword Args:
            state (str): defaults value is set to \"all\". [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [AccountOrderRecord]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['user_id'] = \
            user_id
        kwargs['user_secret'] = \
            user_secret
        kwargs['account_id'] = \
            account_id
        return self.get_user_account_orders_endpoint.call_with_http_info(**kwargs)

    def get_user_account_positions(
        self,
        user_id,
        user_secret,
        account_id,
        **kwargs
    ):
        """Get all positions of an investment account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_user_account_positions(user_id, user_secret, account_id, async_req=True)
        >>> result = thread.get()

        Args:
            user_id (str):
            user_secret (str):
            account_id (str): The ID of the account get positions.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [Position]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['user_id'] = \
            user_id
        kwargs['user_secret'] = \
            user_secret
        kwargs['account_id'] = \
            account_id
        return self.get_user_account_positions_endpoint.call_with_http_info(**kwargs)

    def get_user_holdings(
        self,
        account_id,
        user_id,
        user_secret,
        **kwargs
    ):
        """List balances, positions and orders for the specified account.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_user_holdings(account_id, user_id, user_secret, async_req=True)
        >>> result = thread.get()

        Args:
            account_id (str): The ID of the account to fetch holdings for.
            user_id (str):
            user_secret (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            AccountHoldings
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['account_id'] = \
            account_id
        kwargs['user_id'] = \
            user_id
        kwargs['user_secret'] = \
            user_secret
        return self.get_user_holdings_endpoint.call_with_http_info(**kwargs)

    def list_user_accounts(
        self,
        user_id,
        user_secret,
        **kwargs
    ):
        """List all investment accounts for the user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_user_accounts(user_id, user_secret, async_req=True)
        >>> result = thread.get()

        Args:
            user_id (str):
            user_secret (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [Account]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['user_id'] = \
            user_id
        kwargs['user_secret'] = \
            user_secret
        return self.list_user_accounts_endpoint.call_with_http_info(**kwargs)

    def update_user_account(
        self,
        user_id,
        user_secret,
        account_id,
        **kwargs
    ):
        """Update details of an investment account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_user_account(user_id, user_secret, account_id, async_req=True)
        >>> result = thread.get()

        Args:
            user_id (str):
            user_secret (str):
            account_id (str): The ID of the account to update.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            [Account]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['user_id'] = \
            user_id
        kwargs['user_secret'] = \
            user_secret
        kwargs['account_id'] = \
            account_id
        return self.update_user_account_endpoint.call_with_http_info(**kwargs)




"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import sys
import unittest

import snaptrade_client
from snaptrade_client.model.account_simple import AccountSimple
from snaptrade_client.model.currency import Currency
from snaptrade_client.model.options_symbol import OptionsSymbol
from snaptrade_client.model.symbol import Symbol
globals()['AccountSimple'] = AccountSimple
globals()['Currency'] = Currency
globals()['OptionsSymbol'] = OptionsSymbol
globals()['Symbol'] = Symbol
from snaptrade_client.model.universal_activity import UniversalActivity


class TestUniversalActivity(unittest.TestCase):
    """UniversalActivity unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUniversalActivity(self):
        """Test UniversalActivity"""
        # FIXME: construct object with mandatory attributes with example values
        # model = UniversalActivity()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import unittest

import snaptrade_client
from snaptrade_client.api.portfolio_management_api import PortfolioManagementApi  # noqa: E501


class TestPortfolioManagementApi(unittest.TestCase):
    """PortfolioManagementApi unit test stubs"""

    def setUp(self):
        self.api = PortfolioManagementApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_portfolio_excluded_asset(self):
        """Test case for add_portfolio_excluded_asset

        Adds an asset to exclude to a portfolio group  # noqa: E501
        """
        pass

    def test_create(self):
        """Test case for create

        Create new portfolio group  # noqa: E501
        """
        pass

    def test_create_asset_class(self):
        """Test case for create_asset_class

        Create a new model asset class  # noqa: E501
        """
        pass

    def test_create_model_portfolio(self):
        """Test case for create_model_portfolio

        Creates a new model portfolio  # noqa: E501
        """
        pass

    def test_delete_asset_class(self):
        """Test case for delete_asset_class

        Deletes a model asset class  # noqa: E501
        """
        pass

    def test_delete_excluded_asset(self):
        """Test case for delete_excluded_asset

        Unexclude an asset from a portfolio group  # noqa: E501
        """
        pass

    def test_delete_model_portfolio_by_id(self):
        """Test case for delete_model_portfolio_by_id

        Deletes a model portfolio  # noqa: E501
        """
        pass

    def test_delete_portfoli(self):
        """Test case for delete_portfoli

        Remove a target portfolio.  # noqa: E501
        """
        pass

    def test_delete_portfolio_target_by_id(self):
        """Test case for delete_portfolio_target_by_id

        Remove a TargetAsset.  # noqa: E501
        """
        pass

    def test_detail_asset_class(self):
        """Test case for detail_asset_class

        Get details of a model asset class  # noqa: E501
        """
        pass

    def test_get_calculated_trade_by_id(self):
        """Test case for get_calculated_trade_by_id

        Return an individual trade  # noqa: E501
        """
        pass

    def test_get_model_details_by_id(self):
        """Test case for get_model_details_by_id

        Get details of a model portfolio  # noqa: E501
        """
        pass

    def test_get_portfolio_balances(self):
        """Test case for get_portfolio_balances

        Get sum of cash balances in portfolio group  # noqa: E501
        """
        pass

    def test_get_portfolio_details_by_id(self):
        """Test case for get_portfolio_details_by_id

        Get details of a target portfolio  # noqa: E501
        """
        pass

    def test_get_portfolio_info(self):
        """Test case for get_portfolio_info

        Return a whole bunch of relevant information relating to a portfolio group.  # noqa: E501
        """
        pass

    def test_get_portfolio_positions(self):
        """Test case for get_portfolio_positions

        Get total of each postions owned in portfolio group  # noqa: E501
        """
        pass

    def test_get_portfolio_settings(self):
        """Test case for get_portfolio_settings

        Get portfolio group settings  # noqa: E501
        """
        pass

    def test_get_portfolio_target_by_id(self):
        """Test case for get_portfolio_target_by_id

        Get a specific target from a portfolio group  # noqa: E501
        """
        pass

    def test_get_portfolio_targets(self):
        """Test case for get_portfolio_targets

        Get all target assets under the specified PortfolioGroup.  # noqa: E501
        """
        pass

    def test_get_portoflio_excluded_assets(self):
        """Test case for get_portoflio_excluded_assets

        Get an array of excluded assets associated with a portfolio group\\  # noqa: E501
        """
        pass

    def test_import_model_portfolio(self):
        """Test case for import_model_portfolio

        Import target allocation based on portfolio group  # noqa: E501
        """
        pass

    def test_list(self):
        """Test case for list

        List all portfolio groups  # noqa: E501
        """
        pass

    def test_list_asset_classes(self):
        """Test case for list_asset_classes

        List of model asset class  # noqa: E501
        """
        pass

    def test_list_calculated_trades(self):
        """Test case for list_calculated_trades

        List of trades to make to rebalance portfolio group  # noqa: E501
        """
        pass

    def test_list_model_portfolio(self):
        """Test case for list_model_portfolio

        List of model portfolio  # noqa: E501
        """
        pass

    def test_list_portfolio_accounts(self):
        """Test case for list_portfolio_accounts

        Get all accounts associated with a portfolio group  # noqa: E501
        """
        pass

    def test_modify_model_portfolio_by_id(self):
        """Test case for modify_model_portfolio_by_id

        Updates model portfolio object  # noqa: E501
        """
        pass

    def test_save_portfolio(self):
        """Test case for save_portfolio

        Update an existing target portfolio.  # noqa: E501
        """
        pass

    def test_search_portfolio_symbols(self):
        """Test case for search_portfolio_symbols

        Search for symbols limited to brokerages under the specified portfolio group  # noqa: E501
        """
        pass

    def test_set_portfolio_targets(self):
        """Test case for set_portfolio_targets

        Set a new list of target assets under the specified PortfolioGroup. All existing target assets under this portfolio group will be replaced with the new list.  # noqa: E501
        """
        pass

    def test_update_asset_class(self):
        """Test case for update_asset_class

        Updates model asset class objects  # noqa: E501
        """
        pass

    def test_update_portfolio_settings(self):
        """Test case for update_portfolio_settings

        Updates portfolio group settings  # noqa: E501
        """
        pass

    def test_update_portfolio_target_by_id(self):
        """Test case for update_portfolio_target_by_id

        Update a TargetAsset under the specified PortfolioGroup.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import unittest

import snaptrade_client
from snaptrade_client.api.reference_data_api import ReferenceDataApi  # noqa: E501


class TestReferenceDataApi(unittest.TestCase):
    """ReferenceDataApi unit test stubs"""

    def setUp(self):
        self.api = ReferenceDataApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_currency_exchange_rate_pair(self):
        """Test case for get_currency_exchange_rate_pair

        Return the exchange rate of a currency pair  # noqa: E501
        """
        pass

    def test_get_partner_info(self):
        """Test case for get_partner_info

        Get metadata related to Snaptrade partner  # noqa: E501
        """
        pass

    def test_get_security_types(self):
        """Test case for get_security_types

        List of all security types.  # noqa: E501
        """
        pass

    def test_get_stock_exchanges(self):
        """Test case for get_stock_exchanges

        Return list of stock exchanges on Passiv and their suffixes  # noqa: E501
        """
        pass

    def test_get_symbols(self):
        """Test case for get_symbols

        Search for symbols  # noqa: E501
        """
        pass

    def test_get_symbols_by_ticker(self):
        """Test case for get_symbols_by_ticker

        Get details of a symbol by the ticker  # noqa: E501
        """
        pass

    def test_list_all_brokerage_authorization_type(self):
        """Test case for list_all_brokerage_authorization_type

        List of all brokerage authorization types  # noqa: E501
        """
        pass

    def test_list_all_brokerages(self):
        """Test case for list_all_brokerages

        List of all brokerages.  # noqa: E501
        """
        pass

    def test_list_all_currencies(self):
        """Test case for list_all_currencies

        List of all supported currencies  # noqa: E501
        """
        pass

    def test_list_all_currencies_rates(self):
        """Test case for list_all_currencies_rates

        Return the exchange rates of all supported currencies  # noqa: E501
        """
        pass

    def test_symbol_search_user_account(self):
        """Test case for symbol_search_user_account

        Search for symbols that are supported by a brokerage account using a substring  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import sys
import unittest

import snaptrade_client
from snaptrade_client.model.balance import Balance
from snaptrade_client.model.brokerage_authorization import BrokerageAuthorization
from snaptrade_client.model.calculated_trade import CalculatedTrade
from snaptrade_client.model.excluded_asset import ExcludedAsset
from snaptrade_client.model.portfolio_group_settings import PortfolioGroupSettings
from snaptrade_client.model.position import Position
from snaptrade_client.model.target_asset import TargetAsset
from snaptrade_client.model.universal_symbol import UniversalSymbol
globals()['Balance'] = Balance
globals()['BrokerageAuthorization'] = BrokerageAuthorization
globals()['CalculatedTrade'] = CalculatedTrade
globals()['ExcludedAsset'] = ExcludedAsset
globals()['PortfolioGroupSettings'] = PortfolioGroupSettings
globals()['Position'] = Position
globals()['TargetAsset'] = TargetAsset
globals()['UniversalSymbol'] = UniversalSymbol
from snaptrade_client.model.portfolio_group_info import PortfolioGroupInfo


class TestPortfolioGroupInfo(unittest.TestCase):
    """PortfolioGroupInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPortfolioGroupInfo(self):
        """Test PortfolioGroupInfo"""
        # FIXME: construct object with mandatory attributes with example values
        # model = PortfolioGroupInfo()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import unittest

import snaptrade_client
from snaptrade_client.api.transactions_and_reporting_api import TransactionsAndReportingApi  # noqa: E501


class TestTransactionsAndReportingApi(unittest.TestCase):
    """TransactionsAndReportingApi unit test stubs"""

    def setUp(self):
        self.api = TransactionsAndReportingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_activities(self):
        """Test case for get_activities

        Get transaction history for a user  # noqa: E501
        """
        pass

    def test_get_reporting_custom_range(self):
        """Test case for get_reporting_custom_range

        Get performance information for a specific timeframe  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from snaptrade_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from snaptrade_client.model.api_disclaimer_accept_request import APIDisclaimerAcceptRequest
from snaptrade_client.model.account import Account
from snaptrade_client.model.account_holdings import AccountHoldings
from snaptrade_client.model.account_order_record import AccountOrderRecord
from snaptrade_client.model.account_order_record_status import AccountOrderRecordStatus
from snaptrade_client.model.account_simple import AccountSimple
from snaptrade_client.model.action import Action
from snaptrade_client.model.authentication_login_snap_trade_user200_response import AuthenticationLoginSnapTradeUser200Response
from snaptrade_client.model.balance import Balance
from snaptrade_client.model.brokerage import Brokerage
from snaptrade_client.model.brokerage_authorization import BrokerageAuthorization
from snaptrade_client.model.brokerage_authorization_type import BrokerageAuthorizationType
from snaptrade_client.model.brokerage_authorization_type_read_only import BrokerageAuthorizationTypeReadOnly
from snaptrade_client.model.brokerage_authorization_type_read_only_brokerage import BrokerageAuthorizationTypeReadOnlyBrokerage
from snaptrade_client.model.brokerage_symbol import BrokerageSymbol
from snaptrade_client.model.brokerage_type import BrokerageType
from snaptrade_client.model.calculated_trade import CalculatedTrade
from snaptrade_client.model.cash_restriction import CashRestriction
from snaptrade_client.model.currency import Currency
from snaptrade_client.model.delete_user_response import DeleteUserResponse
from snaptrade_client.model.dividend_at_date import DividendAtDate
from snaptrade_client.model.encrypted_response import EncryptedResponse
from snaptrade_client.model.encrypted_response_encrypted_message_data import EncryptedResponseEncryptedMessageData
from snaptrade_client.model.exchange import Exchange
from snaptrade_client.model.exchange_rate_pairs import ExchangeRatePairs
from snaptrade_client.model.excluded_asset import ExcludedAsset
from snaptrade_client.model.jwt import JWT
from snaptrade_client.model.login_redirect_uri import LoginRedirectURI
from snaptrade_client.model.manual_trade import ManualTrade
from snaptrade_client.model.manual_trade_and_impact import ManualTradeAndImpact
from snaptrade_client.model.manual_trade_balance import ManualTradeBalance
from snaptrade_client.model.manual_trade_form import ManualTradeForm
from snaptrade_client.model.manual_trade_symbol import ManualTradeSymbol
from snaptrade_client.model.model400_failed_request_response import Model400FailedRequestResponse
from snaptrade_client.model.model401_failed_request_response import Model401FailedRequestResponse
from snaptrade_client.model.model403_failed_request_response import Model403FailedRequestResponse
from snaptrade_client.model.model404_failed_request_response import Model404FailedRequestResponse
from snaptrade_client.model.model_asset_class import ModelAssetClass
from snaptrade_client.model.model_asset_class_details import ModelAssetClassDetails
from snaptrade_client.model.model_asset_class_target import ModelAssetClassTarget
from snaptrade_client.model.model_portfolio import ModelPortfolio
from snaptrade_client.model.model_portfolio_asset_class import ModelPortfolioAssetClass
from snaptrade_client.model.model_portfolio_details import ModelPortfolioDetails
from snaptrade_client.model.model_portfolio_security import ModelPortfolioSecurity
from snaptrade_client.model.monthly_dividends import MonthlyDividends
from snaptrade_client.model.net_contributions import NetContributions
from snaptrade_client.model.net_dividend import NetDividend
from snaptrade_client.model.option_chain import OptionChain
from snaptrade_client.model.option_chain_inner import OptionChainInner
from snaptrade_client.model.option_chain_inner_chain_per_root_inner import OptionChainInnerChainPerRootInner
from snaptrade_client.model.option_chain_inner_chain_per_root_inner_chain_per_strike_price_inner import OptionChainInnerChainPerRootInnerChainPerStrikePriceInner
from snaptrade_client.model.option_leg import OptionLeg
from snaptrade_client.model.option_strategy import OptionStrategy
from snaptrade_client.model.option_strategy_legs_inner import OptionStrategyLegsInner
from snaptrade_client.model.options_get_option_strategy_request import OptionsGetOptionStrategyRequest
from snaptrade_client.model.options_holdings import OptionsHoldings
from snaptrade_client.model.options_place_option_strategy_request import OptionsPlaceOptionStrategyRequest
from snaptrade_client.model.options_position import OptionsPosition
from snaptrade_client.model.options_symbol import OptionsSymbol
from snaptrade_client.model.order_type import OrderType
from snaptrade_client.model.partner_data import PartnerData
from snaptrade_client.model.past_value import PastValue
from snaptrade_client.model.percent import Percent
from snaptrade_client.model.performance_custom import PerformanceCustom
from snaptrade_client.model.portfolio_group import PortfolioGroup
from snaptrade_client.model.portfolio_group_info import PortfolioGroupInfo
from snaptrade_client.model.portfolio_group_position import PortfolioGroupPosition
from snaptrade_client.model.portfolio_group_settings import PortfolioGroupSettings
from snaptrade_client.model.position import Position
from snaptrade_client.model.position_symbol import PositionSymbol
from snaptrade_client.model.redirect_tokenand_pin import RedirectTokenandPin
from snaptrade_client.model.security_type import SecurityType
from snaptrade_client.model.snap_trade_api_disclaimer_accept_status import SnapTradeAPIDisclaimerAcceptStatus
from snaptrade_client.model.snap_trade_holdings_account import SnapTradeHoldingsAccount
from snaptrade_client.model.snap_trade_holdings_total_value import SnapTradeHoldingsTotalValue
from snaptrade_client.model.snap_trade_login_user_request_body import SnapTradeLoginUserRequestBody
from snaptrade_client.model.snap_trade_register_user_request_body import SnapTradeRegisterUserRequestBody
from snaptrade_client.model.status import Status
from snaptrade_client.model.strategy_impact import StrategyImpact
from snaptrade_client.model.strategy_impact_legs_inner import StrategyImpactLegsInner
from snaptrade_client.model.strategy_order_place import StrategyOrderPlace
from snaptrade_client.model.strategy_order_place_orders_inner import StrategyOrderPlaceOrdersInner
from snaptrade_client.model.strategy_order_place_orders_inner_legs_inner import StrategyOrderPlaceOrdersInnerLegsInner
from snaptrade_client.model.strategy_order_record import StrategyOrderRecord
from snaptrade_client.model.strategy_quotes import StrategyQuotes
from snaptrade_client.model.strategy_quotes_greek import StrategyQuotesGreek
from snaptrade_client.model.sub_period_return_rate import SubPeriodReturnRate
from snaptrade_client.model.symbol import Symbol
from snaptrade_client.model.symbol_query import SymbolQuery
from snaptrade_client.model.symbols_quotes import SymbolsQuotes
from snaptrade_client.model.target_asset import TargetAsset
from snaptrade_client.model.target_asset_list import TargetAssetList
from snaptrade_client.model.time_in_force import TimeInForce
from snaptrade_client.model.trade import Trade
from snaptrade_client.model.trade_execution_status import TradeExecutionStatus
from snaptrade_client.model.trade_impact import TradeImpact
from snaptrade_client.model.trading_place_oco_order_request import TradingPlaceOCOOrderRequest
from snaptrade_client.model.us_exchange import USExchange
from snaptrade_client.model.underlying_symbol import UnderlyingSymbol
from snaptrade_client.model.universal_activity import UniversalActivity
from snaptrade_client.model.universal_symbol import UniversalSymbol
from snaptrade_client.model.universal_symbol_ticker import UniversalSymbolTicker
from snaptrade_client.model.user_error_log import UserErrorLog
from snaptrade_client.model.user_i_dand_secret import UserIDandSecret
from snaptrade_client.model.user_list import UserList
from snaptrade_client.model.user_settings import UserSettings



"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import os
import unittest
import uuid
import snaptrade_client
from pprint import pprint
from snaptrade_client.api import api_status_api
from snaptrade_client.api import authentication_api
from snaptrade_client.api import account_information_api
from snaptrade_client.api import portfolio_management_api
from snaptrade_client.api import api_disclaimer_api
from snaptrade_client.model.portfolio_group import PortfolioGroup
from snaptrade_client.model.snap_trade_register_user_request_body import SnapTradeRegisterUserRequestBody
from snaptrade_client.model.api_disclaimer_accept_request import APIDisclaimerAcceptRequest


class TestGettingStarted(unittest.TestCase):
    """AccountHoldings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGettingStarted(self):
        # 1) Initialize a client with your clientID and consumerKey.
        configuration = snaptrade_client.Configuration(client_id=os.environ["SNAPTRADE_CLIENT_ID"],
                                                    consumer_key=os.environ['SNAPTRADE_CONSUMER_KEY'])

        with snaptrade_client.ApiClient(configuration) as api_client:
            # 2) Check that the client is able to make a request to the API server.
            api_status_api_inst = api_status_api.APIStatusApi(api_client)
            api_response = api_status_api_inst.check()
            pprint(api_response)

            # 3) Create a new user on SnapTrade
            user_id = str(uuid.uuid4())
            authentication_api_inst = authentication_api.AuthenticationApi(api_client)
            register_response = authentication_api_inst.register_snap_trade_user(
                SnapTradeRegisterUserRequestBody(user_id=user_id))
            pprint(register_response)

            # Note: A user secret is only generated once. It's required to access
            # resources for certain endpoints.
            user_secret = register_response.user_secret

            # 4) Get a redirect URI. Users will need this to connect
            # their brokerage to the SnapTrade server.
            redirect_uri = authentication_api_inst.login_snap_trade_user(user_id, user_secret)
            print(redirect_uri)

            portfolio_management_api_inst = portfolio_management_api.PortfolioManagementApi(api_client)
            portfolio_management_api_inst.create(user_id, user_secret,
                                                                PortfolioGroup(id=str(uuid.uuid4()), name="MyPortfolio"))
            res = portfolio_management_api_inst.list(user_id, user_secret)
            pprint(res)

            api_disclaimer_api_inst = api_disclaimer_api.APIDisclaimerApi(api_client)
            api_disclaimer_api_inst.accept(user_id, user_secret, APIDisclaimerAcceptRequest(accepted=True))

            # 5) Obtaining account holdings data
            account_information_api_inst = account_information_api.AccountInformationApi(api_client)
            holdings = account_information_api_inst.get_all_user_holdings(user_id, user_secret)
            pprint(holdings)

            # 6) Deleting a user
            deleted_response = authentication_api_inst.delete_snap_trade_user(user_id)
            pprint(deleted_response)


if __name__ == '__main__':
    unittest.main()
